import pytest

from gso.products.product_types.switch import Switch
from test.workflows import (
    assert_complete,
    assert_suspended,
    extract_state,
    resume_workflow,
    run_workflow,
)


@pytest.mark.workflow()
def test_activate_switch_success(
    switch_subscription_factory,
    faker,
):
    #  Set up mock return values
    product_id = switch_subscription_factory(status="provisioning")
    #  Sanity check
    assert Switch.from_subscription(product_id).status == "provisioning"

    #  Run workflow
    initial_input_data = [{"subscription_id": product_id}, {}]
    result, process_stat, step_log = run_workflow("activate_switch", initial_input_data)

    assert_suspended(result)
    result, step_log = resume_workflow(process_stat, step_log, input_data=[{"checklist_url": "http://localhost"}])

    assert_complete(result)

    state = extract_state(result)
    subscription_id = state["subscription_id"]
    subscription = Switch.from_subscription(subscription_id)

    assert subscription.status == "active"
